@@ -170,11 +170,11 @@ class PolygonPMV(object):
     @property
     def comfort_parameter(self):
         """PMV comfort parameters that are assigned to this object."""
-        return self._comfort_par.duplicate()  # duplicate since ppd_thresh is setable
+        return self._comfort_par.duplicate()  # duplicate since ppd_thresh is set-able
 
     @property
     def polygon_count(self):
-        """Integer for the number of comfort polygons contined on the object."""
+        """Integer for the number of comfort polygons contained on the object."""
         return self._polygon_count
 
     @property
@@ -231,7 +231,7 @@ class PolygonPMV(object):
 
     @property
     def comfort_values(self):
-        """A tuple of tuples with each sub-tuple representing one of the comfort polygons.
+        """A tuple of tuples with each sub-tuple representing one of comfort polygons.
 
         Each sub-tuple contains 0/1 values for whether the point is inside the
         comfort polygon or not.
@@ -266,7 +266,7 @@ class PolygonPMV(object):
 
     @property
     def merged_comfort_data(self):
-        """A data collection or 0/1 for whether the data is in the merged comfort polygon.
+        """A data collection or 0/1 for whether the data is in merged comfort polygon.
         """
         if self._merged_comfort_data is None:
             if len(self.merged_comfort_values) == 1:
@@ -291,7 +291,7 @@ class PolygonPMV(object):
         return self.merged_comfort_polygon[0][0].x <= psy.base_point.x
 
     def evaporative_cooling_polygon(self):
-        """Get a tuple of Polyline2D and LineSegment2D for an evaporative cooling polygon.
+        """Get a tuple of Polyline2D and LineSegment2D for evaporative cooling polygon.
 
         This will be None if the polygon does not fit on the chart.
         """
@@ -495,8 +495,8 @@ class PolygonPMV(object):
             hr_e = humid_ratio_from_db_rh(min_tc, 100, psy.average_pressure)
             hr_y = psy.hr_y_value(hr_e)
             hr_y = hr_y if hr_y < comf_poly[0][0].y else comf_poly[0][0].y
-            left1 = Point2D(psy.basepoint.x, hr_y)
-            left2 = Point2D(psy.basepoint.x, comf_poly[0][-1].y)
+            left1 = Point2D(psy.base_point.x, hr_y)
+            left2 = Point2D(psy.base_point.x, comf_poly[0][-1].y)
         left_lin = LineSegment2D.from_end_points(left1, left2)
 
         # get the bottom line and the line bordering the comfort polygon
@@ -639,6 +639,32 @@ class PolygonPMV(object):
         sol_lines.append(LineSegment2D.from_end_points(l_pt, right[0]))
         return sol_lines
 
+    def shade_line(self, balance_temperature=None):
+        """Get a Polyline2D or LineSegment2D for the line above which shade is needed.
+
+        The purpose of this line is to show which other polygons may not work as
+        intended if there is no shade available. This will be None if the line
+        does not fit on the chart.
+
+        Args:
+            balance_temperature: An optional balance temperature of the building
+                to which the shade is applied (Celsius). Must be greater or equal to 5 C.
+                In order for this method to not return None, this value must be
+                less than the coldest temperature of the merged comfort
+                polygon. If None, the shade line will be at the lower edge of the
+                comfort polygon, essentially assuming that the shade is applied
+                directly to the occupant, who is not inside of a building.
+        """
+        psy = self._psychrometric_chart
+        # check to be sure the shade line fits on the chart
+        self._balance_check(balance_temperature)
+        comf_poly = self.merged_comfort_polygon
+        bal = balance_temperature if not psy.use_ip else \
+            self.TEMP_TYPE.to_unit([balance_temperature], 'F', 'C')[0]
+        bal_x = psy.t_x_value(bal)
+        if self.is_comfort_too_cold or comf_poly[0][0].x < bal_x:
+            return None
+
     def evaluate_polygon(self, polygon, tolerance=0.01):
         """Evaluate a strategy polygon in relation to the data points of the chart.
 
@@ -768,7 +794,7 @@ class PolygonPMV(object):
         if len(temp_vals) == 1:
             t = temp_vals[0]
             val = 1 if bal_temp - 20 < t < bal_temp and comf_val[0] == 0 else 0
-            return([val]), 20
+            return ([val]), 20
         else:  # make sure the collection is hourly continuous
             time_ind = self._check_hourly(incident_irradiance, 'Passive Solar')
             tcon_i = time_constant * incident_irradiance.header.analysis_period.timestep
